==> guile-2.0.12-x86_64-1.txz: usr/lib64/guile/2.0/ccache/ice-9/rdelim.go <==
GOOF----LE-8-2.0W      ] h 4      h3      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  rdelim	 		g  filenameS	
f  ice-9/rdelim.scm	g  exportsS	g  	read-line	
g  
read-line!	g  read-delimited	g  read-delimited!	g  read-string	g  read-string!	g  %read-delimited!	g  
%read-line	g  
write-line	
 		g  set-current-module	 	 	g  %init-rdelim-builtins	g  current-input-port	f  
	g  eof-object?	g  trim	g  
string-length	g  peek	 g  split	!g  concat	"g  string-set!	#g  error	$f  unexpected handle-delim value: 	%g  make-string	&g  string-concatenate-reverse	'g  	substring	(g  
string-append	)g  string	*g  make-syntax-transformer	+* 	,* 	-g  	check-arg	.g  macro	/g  $sc-dispatch	0/ 	1/ 	2g  any	3g  each-any	423	524	625	7g  
syntax-object	8g  unless	9g  top	:9 	;g  ribcage	<g  dummy	=g  exp	>g  message	?g  arg	@<=>? 	Ag  m-GH54W3Tx5KTiL90FylbziD-17609	BA9 	CB::: 	Df  l-GH54W3Tx5KTiL90FylbziD-17614	Ef  l-GH54W3Tx5KTiL90FylbziD-17615	Ff  l-GH54W3Tx5KTiL90FylbziD-17616	Gf  l-GH54W3Tx5KTiL90FylbziD-17617	HDEFG 	I;@CH 	J; 	Kg  x	LK 	MB 	Nf  l-GH54W3Tx5KTiL90FylbziD-17611	ON 	P;LMO 	Q:IJP 	Rg  hygiene	SR 	T78QS 	U7#QS 	Vg  syntax-violation	WV 	XV 	Yf  -source expression failed to match any pattern	Zg  integer?	[g  exact?	\g  index?	]g  string?	^f  not a string	_f  	bad index	`f  start beyond end	af  end beyond string length	bg  	read-char	cg  list->string	dg  reverse!	eg  reverse	fg  char?	gg  unread-charC 5h      ]4	
5 4 >  "  G   4i>   "  G    h`   $  - . , 3 #  4 5"  $  CC
$  45$  C""           g  string
		[ g  port		[ g  rv		"	[ g  
terminator		'	[ g  nchars		,	[  g  filenamef  ice-9/rdelim.scm
	&
		)	
		(	 	"	)	
	"	)		'	-		'	)		,	.		,	)		8	/		A	/		E	/		F	0		P	/	 		[  g  nameg  
read-line! C
R !"#$       h   :  - . , 3 	#  45 #  #  
#  	454 5$  45"  $  *
$  &  CC&  CC$  "  $  C$  4	>  "  G  C$  C
6     2      g  delims
	  g  buf	  g  port		  g  handle-delim		  g  start		  g  end		  g  rv		P  g  
terminator		U  g  nchars		Z   	g  filenamef  ice-9/rdelim.scm
	5
		6	 	!	6	D	3	7	)	<	8	
	F	:	6	G	:	$	H	:		P	8	
	P	8		U	>		U	8		Z	?		Z	8		b	@		c	A		n	@		r	@		u	B		z	B		~	C	% 	C	 	D	 	F	% 	F	 	G	 	J	 	L	 	L	( 	L	 	M	 	J	 	N	 	O	 	O	 $	 		  g  nameg  read-delimited! CR%&'!() #$   h     - . , 3 #  45 #  "  454 5		
$  "  i44
	55$  4	5$  C
456$  "  $  C$  C
64	5$  

$  &  CC"o"k4
	5
	"
	d"       g  delims
	 g  port	 g  handle-delim		 g  
substrings		' g  total-chars		' g  buf-size		' g  buf		. g  rv		A g  
terminator		F g  nchars			K g  	new-total	
	R g  joined		p   g  filenamef  ice-9/rdelim.scm
	R
		R	1	!	S	'	'	T		(	W		.	W		1	X		;	Z	8	<	Z	&	=	Z	!	A	X		A	W		F	\		F	W		K	]		K	W		R	^		R	W		Z	_		_	k		b	l		n	l		p	k		p	j		{	m	
	|	o	 	o	
 	q	' 	q	 	m	
 	s	 	t	 	t	 	_	 	e	
 	_	 	e	& 	e	 	f	 	f	 	g	 	b	 	b		d		b		T		T		T	 1		  g  nameg  read-delimited CR4,-.16TU        h   d   ] C      \       g  dummy
		 g  exp		 g  message			 g  arg			  			   CXY     h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  ice-9/rdelim.scm
	w
 		"  g  
macro-typeg  syntax-rulesg  patternsg  expg  messageg  argg  ...   C5-RZ[        h(      ]4 5$  4 5$   
CCC              g  n
		!  g  filenamef  ice-9/rdelim.scm
	{
		|		
	|			|			|			|	 		!  g  nameg  index? C\R]#^\_`ab" 
   h8    - . , 3 #  45 #  
#  	4 54 5$  "  4 >  "  G  45$  "  4>  "  G  45$  "  4>  "  G  $  "  4>  "  G  4 5$  "  4	>  "  G  "  H$  94
545$  C4 >  "  G  "C"       g  buf
	7 g  port	7 g  start		7 g  end		7 g  n	 / g  c	 )  g  filenamef  ice-9/rdelim.scm
	~
				) 	&	2 	
	< 		E 		L 		U 	
	_ 		h 		o 		x 	
  	  	  	  	
  	  	  	  	  	
  	  	*  	  	  	  	  	  	  	 	
	 	 	# 	) 	. 	/ 	 &	7	  g  nameg  read-string!g  
documentationf NRead all of the characters out of PORT and write them to BUF.
Returns the number of characters read.

This function only reads out characters from PORT if it will be able to
write them to BUF.  That is to say, if BUF is smaller than the number of
available characters, then BUF will be filled, and characters will be
left in the port. CRbcde  h     *    N. +   E3  #  45  "  *4 545$  456""]""  D4 545$  "  $  456"
"      g  port
		T g  chars	#	M g  char		*	M g  port
	V  g  count	V  g  chars		Z  g  total		Z  g  char		a  g  t		j	  	g  filenamef  ice-9/rdelim.scm
 		 		# 		$ 		* 		- 		7 		: 		B 		G 		M 		M 		N 		T 		V 		Z 		[ 		a 		d 		j 		| 	#  	  	  	  	  	$  	  	  	  	 		T
 	V 	  g  nameg  read-stringg  
documentationf  Read all of the characters out of PORT and return them as a string.
If the COUNT argument is present, treat it as a limit to the number of
characters to read.  By default, there is no limit. CR !]f()g#$        h     -  . , 3  #  45  #  4 5$  C$  C$  )45$  45$  
4	56CC
$  &45$  4 >  "  G  "   C
6       g  port
	  g  handle-delim	  g  
line/delim		*  g  line		/  g  delim		4   g  filenamef  ice-9/rdelim.scm
 
	 	%	! 	"	$ 		* 		/ 		/ 		4 		4 		? 		X 		b 		c 	(	m 		r 	(	z 	  	  	  	  	  	  	 	 
	  g  nameg  	read-line CRC             g  m
		(  g  filenamef  ice-9/rdelim.scm		
	)	$
	&
5	5
	|	R
	{
	~
 
 
 
	
   C6 

==> guile-2.0.13-x86_64-1.txz: usr/lib64/guile/2.0/ccache/ice-9/rdelim.go <==
GOOF----LE-8-2.0W      ] h 4      h3      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  rdelim	 		g  filenameS	
f  ice-9/rdelim.scm	g  exportsS	g  	read-line	
g  
read-line!	g  read-delimited	g  read-delimited!	g  read-string	g  read-string!	g  %read-delimited!	g  
%read-line	g  
write-line	
 		g  set-current-module	 	 	g  %init-rdelim-builtins	g  current-input-port	f  
	g  eof-object?	g  trim	g  
string-length	g  peek	 g  split	!g  concat	"g  string-set!	#g  error	$f  unexpected handle-delim value: 	%g  make-string	&g  string-concatenate-reverse	'g  	substring	(g  
string-append	)g  string	*g  make-syntax-transformer	+* 	,* 	-g  	check-arg	.g  macro	/g  $sc-dispatch	0/ 	1/ 	2g  any	3g  each-any	423	524	625	7g  
syntax-object	8g  unless	9g  top	:9 	;g  ribcage	<g  dummy	=g  exp	>g  message	?g  arg	@<=>? 	Ag  m-h1BcNVWVTmeS6ZIfDJXgNm-18303	BA9 	CB::: 	Df  l-h1BcNVWVTmeS6ZIfDJXgNm-18308	Ef  l-h1BcNVWVTmeS6ZIfDJXgNm-18309	Ff  l-h1BcNVWVTmeS6ZIfDJXgNm-18310	Gf  l-h1BcNVWVTmeS6ZIfDJXgNm-18311	HDEFG 	I;@CH 	J; 	Kg  x	LK 	MB 	Nf  l-h1BcNVWVTmeS6ZIfDJXgNm-18305	ON 	P;LMO 	Q:IJP 	Rg  hygiene	SR 	T78QS 	U7#QS 	Vg  syntax-violation	WV 	XV 	Yf  -source expression failed to match any pattern	Zg  integer?	[g  exact?	\g  index?	]g  string?	^f  not a string	_f  	bad index	`f  start beyond end	af  end beyond string length	bg  	read-char	cg  list->string	dg  reverse!	eg  reverse	fg  char?	gg  unread-charC 5h      ]4	
5 4 >  "  G   4i>   "  G    h`   $  - . , 3 #  4 5"  $  CC
$  45$  C""           g  string
		[ g  port		[ g  rv		"	[ g  
terminator		'	[ g  nchars		,	[  g  filenamef  ice-9/rdelim.scm
	&
		)	
		(	 	"	)	
	"	)		'	-		'	)		,	.		,	)		8	/		A	/		E	/		F	0		P	/	 		[  g  nameg  
read-line! C
R !"#$       h   :  - . , 3 	#  45 #  #  
#  	454 5$  45"  $  *
$  &  CC&  CC$  "  $  C$  4	>  "  G  C$  C
6     2      g  delims
	  g  buf	  g  port		  g  handle-delim		  g  start		  g  end		  g  rv		P  g  
terminator		U  g  nchars		Z   	g  filenamef  ice-9/rdelim.scm
	5
		6	 	!	6	D	3	7	)	<	8	
	F	:	6	G	:	$	H	:		P	8	
	P	8		U	>		U	8		Z	?		Z	8		b	@		c	A		n	@		r	@		u	B		z	B		~	C	% 	C	 	D	 	F	% 	F	 	G	 	J	 	L	 	L	( 	L	 	M	 	J	 	N	 	O	 	O	 $	 		  g  nameg  read-delimited! CR%&'!() #$   h     - . , 3 #  45 #  "  454 5		
$  "  i44
	55$  4	5$  C
456$  "  $  C$  C
64	5$  

$  &  CC"o"k4
	5
	"
	d"       g  delims
	 g  port	 g  handle-delim		 g  
substrings		' g  total-chars		' g  buf-size		' g  buf		. g  rv		A g  
terminator		F g  nchars			K g  	new-total	
	R g  joined		p   g  filenamef  ice-9/rdelim.scm
	R
		R	1	!	S	'	'	T		(	W		.	W		1	X		;	Z	8	<	Z	&	=	Z	!	A	X		A	W		F	\		F	W		K	]		K	W		R	^		R	W		Z	_		_	k		b	l		n	l		p	k		p	j		{	m	
	|	o	 	o	
 	q	' 	q	 	m	
 	s	 	t	 	t	 	_	 	e	
 	_	 	e	& 	e	 	f	 	f	 	g	 	b	 	b		d		b		T		T		T	 1		  g  nameg  read-delimited CR4,-.16TU        h   d   ] C      \       g  dummy
		 g  exp		 g  message			 g  arg			  			   CXY     h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  ice-9/rdelim.scm
	w
 		"  g  
macro-typeg  syntax-rulesg  patternsg  expg  messageg  argg  ...   C5-RZ[        h(      ]4 5$  4 5$   
CCC              g  n
		!  g  filenamef  ice-9/rdelim.scm
	{
		|		
	|			|			|			|	 		!  g  nameg  index? C\R]#^\_`ab" 
   h8    - . , 3 #  45 #  
#  	4 54 5$  "  4 >  "  G  45$  "  4>  "  G  45$  "  4>  "  G  $  "  4>  "  G  4 5$  "  4	>  "  G  "  H$  94
545$  C4 >  "  G  "C"       g  buf
	7 g  port	7 g  start		7 g  end		7 g  n	 / g  c	 )  g  filenamef  ice-9/rdelim.scm
	~
				) 	&	2 	
	< 		E 		L 		U 	
	_ 		h 		o 		x 	
  	  	  	  	
  	  	  	  	  	
  	  	*  	  	  	  	  	  	  	 	
	 	 	# 	) 	. 	/ 	 &	7	  g  nameg  read-string!g  
documentationf NRead all of the characters out of PORT and write them to BUF.
Returns the number of characters read.

This function only reads out characters from PORT if it will be able to
write them to BUF.  That is to say, if BUF is smaller than the number of
available characters, then BUF will be filled, and characters will be
left in the port. CRbcde  h     *    N. +   E3  #  45  "  *4 545$  456""]""  D4 545$  "  $  456"
"      g  port
		T g  chars	#	M g  char		*	M g  port
	V  g  count	V  g  chars		Z  g  total		Z  g  char		a  g  t		j	  	g  filenamef  ice-9/rdelim.scm
 		 		# 		$ 		* 		- 		7 		: 		B 		G 		M 		M 		N 		T 		V 		Z 		[ 		a 		d 		j 		| 	#  	  	  	  	  	$  	  	  	  	 		T
 	V 	  g  nameg  read-stringg  
documentationf  Read all of the characters out of PORT and return them as a string.
If the COUNT argument is present, treat it as a limit to the number of
characters to read.  By default, there is no limit. CR !]f()g#$        h     -  . , 3  #  45  #  4 5$  C$  C$  )45$  45$  
4	56CC
$  &45$  4 >  "  G  "   C
6       g  port
	  g  handle-delim	  g  
line/delim		*  g  line		/  g  delim		4   g  filenamef  ice-9/rdelim.scm
 
	 	%	! 	"	$ 		* 		/ 		/ 		4 		4 		? 		X 		b 		c 	(	m 		r 	(	z 	  	  	  	  	  	  	 	 
	  g  nameg  	read-line CRC             g  m
		(  g  filenamef  ice-9/rdelim.scm		
	)	$
	&
5	5
	|	R
	{
	~
 
 
 
	
   C6 
